==> zio-aws-kafka_3-5.17.104.10-sources.jar: zio/aws/kafka/model/DescribeConfigurationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeConfigurationRequest(arn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest = {
    import DescribeConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
      .builder()
      .arn(__string.unwrap(arn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DescribeConfigurationRequest.ReadOnly =
    zio.aws.kafka.model.DescribeConfigurationRequest.wrap(buildAwsValue())
}
object DescribeConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DescribeConfigurationRequest =
      zio.aws.kafka.model.DescribeConfigurationRequest(arn)
    def arn: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
  ) extends zio.aws.kafka.model.DescribeConfigurationRequest.ReadOnly {
    override val arn: __string =
      zio.aws.kafka.model.primitives.__string(impl.arn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
  ): zio.aws.kafka.model.DescribeConfigurationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-kafka_3-5.17.295.20-sources.jar: zio/aws/kafka/model/DescribeConfigurationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeConfigurationRequest(arn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest = {
    import DescribeConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
      .builder()
      .arn(arn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DescribeConfigurationRequest.ReadOnly =
    zio.aws.kafka.model.DescribeConfigurationRequest.wrap(buildAwsValue())
}
object DescribeConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DescribeConfigurationRequest =
      zio.aws.kafka.model.DescribeConfigurationRequest(arn)
    def arn: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
  ) extends zio.aws.kafka.model.DescribeConfigurationRequest.ReadOnly {
    override val arn: __string = impl.arn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DescribeConfigurationRequest
  ): zio.aws.kafka.model.DescribeConfigurationRequest.ReadOnly = new Wrapper(
    impl
  )
}
